@@ -25,20 +25,6 @@ class DataRecord:
 class DataTable:
 	con: Optional[PostgresConnection] = None
 
-	@staticmethod
-	def __connect():
-		if DataTable.con:
-			return
-
-		DataTable.con = pg2.connect(
-			database=notnull(getenv('POSTGRES_DBNAME')),
-			host=notnull(getenv('POSTGRES_HOST')),
-			port=notnull(getenv('POSTGRES_PORT')),
-			user=notnull(getenv('POSTGRES_USER')),
-			password=notnull(getenv('POSTGRES_PASSWORD')),
-			options="-c search_path=data"
-		)
-
 	@staticmethod
 	def __get_name(participant: models.Participant) -> str:
 		"""
@@ -59,7 +45,6 @@ class DataTable:
 
 		table_name = DataTable.__get_name(participant=participant)
 
-		DataTable.__connect()
 		cur = DataTable.con.cursor()
 		cur.execute('create schema if not exists data')
 		cur.execute(f'create table if not exists data.{table_name}(data_source_id int references core.data_source (id), ts timestamp, val jsonb)')  # noqa
@@ -80,7 +65,6 @@ class DataTable:
 
 		table_name = DataTable.__get_name(participant=participant)
 
-		DataTable.__connect()
 		cur = DataTable.con.cursor()
 		cur.execute(
 			f'insert into data.{table_name}(data_source_id, ts, val) values (%s,%s,%s)',  # noqa
@@ -102,7 +86,6 @@ class DataTable:
 
 		table_name = DataTable.__get_name(participant=participant)
 
-		DataTable.__connect()
 		cur: pg2_extras.DictCursor = DataTable.con.cursor(cursor_factory=pg2_extras.DictCursor)
 		cur.execute(
 			f'select data_source_id, ts, val from data.{table_name} where data_source_id = %s and ts >= %s limit %s',  # noqa
@@ -126,7 +109,6 @@ class DataTable:
 
 		table_name = DataTable.__get_name(participant=participant)
 
-		DataTable.__connect()
 		cur: pg2_extras.DictCursor = DataTable.con.cursor(cursor_factory=pg2_extras.DictCursor)
 		cur.execute(
 			f'select data_source_id, ts, val from data.{table_name} where data_source_id = %s and ts >= %s and ts < %s',  # noqa
@@ -149,7 +131,6 @@ class DataTable:
 		table_name = DataTable.__get_name(participant=participant)
 		res_filepath = get_temp_filepath(filename=f'{table_name}.csv')
 
-		DataTable.__connect()
 		cur: pg2_extras.DictCursor = DataTable.con.cursor()
 		if data_source is None:
 			with open(file=res_filepath, mode='w') as file:
